#include <Adafruit_NeoPixel.h>
#include <avr/power.h>

//==~~ init strip RGB ~~==// 

#define PIN 3

Adafruit_NeoPixel strip = Adafruit_NeoPixel(60, PIN, NEO_GRB + NEO_KHZ800);


//==~~ init sound ~~==// 

const int sampleWindow = 50;
unsigned int sample;

const int soundPin = A5;
int volume; // en %

uint32_t a3f = strip.Color(170, 255, 48);

//==~~ pin definition ~~==// 

const int buttonPin = 7;
const int potPin = A0;

int oldState;
int mode = 0;
int nModes = 4;
int pot ;
int pos_roll = 0;

void setup() {
  // setup strip RGB
  // This is for Trinket 5V 16MHz, you can remove these three lines if you are not using a Trinket
#if defined (__AVR_ATtiny85__)
  if (F_CPU == 16000000) clock_prescale_set(clock_div_1);
#endif
  // End of trinket special code

  Serial.begin(9600);
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
  
  // setup pin
  pinMode(buttonPin, INPUT);
  digitalWrite(buttonPin, HIGH);
  oldState = digitalRead(buttonPin);
}

void loop() {
  getVolume();
  getMode();
  getPot();
  Serial.print(volume);
  
  Serial.print( "    ");
  Serial.println(mode);
  
  if (mode == 0){
      
  }else if (mode == 1){
    simpleVolume();
 }else if (mode == 2){
   fadeAnim();
 }else if (mode == 3){
   roll(4);
 }
}

void simpleVolume(){
  if (volume > pot){
     double intensity = map(volume, pot, 100, 0.0, 1.0);
     setColor(colA3f(intensity));
  }else{
     setColor(0); 
  }
  delay(50);
}

void fadeVolume(){
   int nLedsOn;
   if (volume > pot){
       nLedsOn = map(volume, pot, 100, 60 , 1);
       oneOnN(nLedsOn);
   } else {
     setColor(0);
  }
  delay(50);
}

void barVolume(int nBar){
   if (volume > pot){
      double intensity = map(volume, pot, 100, 0.0, 1.0);
      nOnN(nBar, intensity);
   }else{
    setColor(0); 
  }
  delay(50);
}

void fadeAnim(){
  int n_min = 3;
  if (volume > pot){
     for (int i = 1; i<n_min; i++){
        oneOnN(2*i);
        delay(5);
     } 
  }
  setColor(0);
  delay(5); 
}

void roll(int nBars){
  int nLeds = 60/(2*nBars);
  int switchch = 1;
  for (int i = 0 ; i < 2*nBars ; i++){
     for (int j = 0 ; j < nLeds; j ++){
        if (switchch){
           strip.setPixelColor((nLeds * i + j + pos_roll)%60, a3f);
        } else{
          strip.setPixelColor((nLeds * i + j + pos_roll)%60, 0);
        }
     }
     switchch = !switchch;
  }
  pos_roll = (pos_roll +2) %60;
  strip.show();
  delay(pot);
  
}
